#!/bin/bash
# $Id: xmlmerge.sh.in,v 1.1 2000/06/06 14:57:20 algernon Exp $
# xmlmerge.sh - a script to replace the xmlmerge utility
# (C) 2000 The MadHouse Project
#
# This script is released under the terms of the GNU
# General Public License. See the COPYING file included
# with the m3x sources for details

gettext=`which gettext`

# This is a pretty function that'll try to translate strings...
# But only if gettext is available.
function g_print ()
{
	if test "x$gettext" != "x"
	then
		gettext -d m3x -e "$1\n"
	else
		echo $1
	fi
}

# Print help.
function print_help ()
{
	g_print "Usage: xmlmerge [OPTIONS] -o output_file files..."
	echo
	g_print "Options:"
	g_print "	--help, -h           : this help screen."
	g_print "	--version, -V        : print version information."
	g_print "	--output [file], -o  : set output file to [file]."
	g_print "	--extra [string], -e : set some extra fields."
	echo
}

FILECOUNT=0

# Do the command line parsing.
while test $# -gt 0
do
	# --output=filename
	if `echo "$1" | grep -q ^--output=`
	then
		OUTFILE=`echo $1 | sed -e "s,^--output=,,"`
		shift OPTIND - 1
	fi
	# parse all other options, that either do not take
	# any arguments, or the option and the argument is
	# separated by a space.
	case "$1" in
		"-V" | "--version")
			g_print "xmlmerge / m3x 0.1.13"
			exit 0
			;;
		"-h" | "--help")
			print_help
			exit 0
			;;
		"-o" | "--output")
			shift
			OUTFILE=$1
			shift
			;;
		*)
			FILES="$FILES $1"
			FILECOUNT=$((FILECOUNT+1))
			shift
			;;
	esac
done

# If we have only one file, bail out...
# If output file is not specified, exit.
if test $FILECOUNT -lt 2 || test "x$OUTFILE" == "x"
then
	print_help
	exit 1
fi

# Generate a temporary file that will store the m3x script.
# This is necessary until --script is not implemented...
tmpfile=`tempfile`

# Now output the m3x script.
echo "new" >$tmpfile

for FILE in $FILES
do
	# This is confusing...
	# Merging is not done here, still we print it here.
	# Should get that damn --script thing working...
	if test -f $FILE
	then
		printf "`g_print "Merging: %s"`\n" $FILE
		echo "import $FILE" >>$tmpfile
	fi
done

echo "config filename $OUTFILE" >>$tmpfile
echo "save" >>$tmpfile
echo "close" >>$tmpfile
echo "exit" >>$tmpfile

# And now execute the generated script.
m3x-text --quiet --exec $tmpfile &>/dev/null

# Then delete the temporary m3x script file.
rm -f $tmpfile
